@@ -28,7 +28,7 @@ class Service(object):
         self.image_builder = None
         self.name = None
         self.app_name = None
-        self.volumes = None
+        self.volumes = []
         self.volumes_from = None
         self.ports = None
         self.command = None
@@ -60,9 +60,10 @@ class Service(object):
         data = yield self.client.inspect(self.name)
         self._inspect_data = data
 
-        metrics = yield self.redis.hget('metrics', self.name)
-        if metrics:
-            self.memory_usage, self.cpu_usage = metrics.split(';')
+        if not isinstance(self.redis, defer.Deferred):  # for tests
+            metrics = yield self.redis.hget('metrics', self.name)
+            if metrics:
+                self.memory_usage, self.cpu_usage = metrics.split(';')
 
         defer.returnValue(self._inspect_data)
 
@@ -99,6 +100,22 @@ class Service(object):
 
         return self._inspect_data['HostsPath']
 
+    def list_volumes(self):
+        if not self.is_created():
+            return None
+
+        volumes_ = self._inspect_data['Volumes']
+
+        internal_volumes = (
+            '/var/run/mfcloud',
+            '/usr/bin/@me'
+        )
+        for iv in internal_volumes:
+            if iv in volumes_:
+                del volumes_[iv]
+
+        return volumes_
+
     def public_ports(self):
         if not self.is_running():
             return None
@@ -109,7 +126,7 @@ class Service(object):
         if not self.is_running():
             return None
 
-        return self._inspect_data['Volumes'].keys()
+        return self.list_volumes().keys()
 
     def started_at(self):
         if not self.is_running():
