@@ -1,21 +1,19 @@
 import inspect
-import logging
 import re
-from autobahn.twisted import wamp
+
 from autobahn.twisted.util import sleep
-from autobahn.twisted.wamp import ApplicationSession
 import inject
-from mfcloud.txdocker import IDockerClient
-from mfcloud.application import ApplicationController, Application, AppDoesNotExist
-from mfcloud.config import ConfigParseError
+from twisted.internet import defer, reactor
+from twisted.internet.defer import inlineCallbacks
+from twisted.python import log
+import txredisapi
+
+from mfcloud.txdocker import IDockerClient, NotFound
+from mfcloud.application import ApplicationController
 from mfcloud.deployment import DeploymentController
 from mfcloud.events import EventBus
 from mfcloud.remote import ApiRpcServer
-from twisted.internet import defer, reactor
-from twisted.internet.defer import Deferred, DeferredList, inlineCallbacks
-import txredisapi
-
-from twisted.python import log
+from mfcloud.volumes import directory_snapshot
 
 
 class TaskService(object):
@@ -59,6 +57,11 @@ class TaskService(object):
         alist = yield self.app_controller.list()
         defer.returnValue(alist)
 
+    @inlineCallbacks
+    def task_list_volumes(self, ticket_id):
+        alist = yield self.app_controller.volume_list()
+        defer.returnValue(alist)
+
     @inlineCallbacks
     def task_list_vars(self, ticket_id):
         vlist = yield self.redis.hgetall('vars')
@@ -84,6 +87,20 @@ class TaskService(object):
         defer.returnValue(ret)
 
 
+    @inlineCallbacks
+    def task_logs(self, ticket_id, name):
+
+        def on_log(log):
+            log = log[8:]
+            self.task_log(ticket_id, log)
+
+        try:
+            client = inject.instance(IDockerClient)
+            yield client.logs(name, on_log, tail=100)
+        except NotFound:
+            self.task_log(ticket_id, 'Container not found by name.')
+
+
     @inlineCallbacks
     def task_status(self, ticket_id, name):
         app = yield self.app_controller.get(name)
@@ -153,6 +170,8 @@ class TaskService(object):
         d.addCallback(done)
         d.addErrback(on_err)
 
+        self.event_bus.once('task.failure.%s' % ticket_id, d.cancel)
+
         return d
 
 
@@ -186,6 +205,7 @@ class TaskService(object):
                 yield service.create(ticket_id)
 
         for service in config.get_services().values():
+
             if service_name and '%s.%s' % (service_name, app_name) != service.name:
                 continue
 
@@ -206,9 +226,9 @@ class TaskService(object):
                     wait = service.wait
                     if wait <= 0:
                         wait = 0.2
-                    if wait > 300:
-                        self.task_log(ticket_id, 'WARN: wait is to high, forcibly set to 300s to prevent memory leaks')
-                        wait = 300
+                    if wait > 3600:
+                        self.task_log(ticket_id, 'WARN: wait is to high, forcibly set to 3600s to prevent memory leaks')
+                        wait = 3600
 
                     log_process = self.follow_logs(service, ticket_id)
 
@@ -293,24 +313,6 @@ class TaskService(object):
         ret = 'Done.'
         defer.returnValue(ret)
 
-
-    @inlineCallbacks
-    def task_push(self, ticket_id, app_name, service_name, volume):
-
-        app = yield self.app_controller.get(app_name)
-        config = yield app.load()
-
-        name = '_volumes_%s.%s' % (service_name, app_name)
-
-        service = config.get_services()[name]
-
-        """
-        @type service: mfcloud.service.Service
-        """
-        port = service.public_ports()['22/tcp'][0]['HostPort']
-
-        defer.returnValue(port)
-
     @inlineCallbacks
     def task_run(self, ticket_id, app_name, service_name):
 
